==> haskell-hls-refine-imports-plugin-2.0.0.0-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refine-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refine-imports-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-refine-imports-plugin-2.0.0.0-KVZteN0OgxT3flNSjUKXaJ
key:                  hls-refine-imports-plugin-2.0.0.0-KVZteN0OgxT3flNSjUKXaJ
license:              Apache-2.0
maintainer:           mnf.shih@gmail.com
author:               rayshih
synopsis:             Refine imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  7a44e618cfcdcd0e730c7e779d32c199
exposed:              True
exposed-modules:      Ide.Plugin.RefineImports
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-refine-imports-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-refine-imports-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-refine-imports-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refine-imports-plugin
hs-libraries:         HShls-refine-imports-plugin-2.0.0.0-KVZteN0OgxT3flNSjUKXaJ
depends:
    aeson-2.1.2.1-CJUEk8Q0QXZ63rfmeHQCzY base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-9.4.8 ghcide-2.0.0.0-H1ICRTE2M66EqglwlJk8PL
    hls-explicit-imports-plugin-2.0.0.0-DdShab2rNmALShQbdC6TD3
    hls-graph-2.0.0.0-1f74GKPKKdD9gllezo6cXg
    hls-plugin-api-2.0.0.0-GY4wpL8VIcU79R7yyVXxr
    lsp-1.6.0.0-Jj5cZac2KShEtujPemnlw4 text-2.0.2
    unordered-containers-0.2.20-4tF6VC1d0ODJ0H7AFNioZw

haddock-interfaces:
    /usr/share/doc/haskell-hls-refine-imports-plugin/html/hls-refine-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refine-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-refine-imports-plugin-2.0.0.0-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refine-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refine-imports-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-refine-imports-plugin-2.0.0.0-GA9SaeZEoGO702cyNQvRnP
key:                  hls-refine-imports-plugin-2.0.0.0-GA9SaeZEoGO702cyNQvRnP
license:              Apache-2.0
maintainer:           mnf.shih@gmail.com
author:               rayshih
synopsis:             Refine imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1c2f169ebab63ec355f63f31be4e7d8f
exposed:              True
exposed-modules:      Ide.Plugin.RefineImports
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-refine-imports-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-refine-imports-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-refine-imports-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refine-imports-plugin
hs-libraries:         HShls-refine-imports-plugin-2.0.0.0-GA9SaeZEoGO702cyNQvRnP
depends:
    aeson-2.1.2.1-GOr0sGsn8HVJzt9KhewtB0 base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-9.4.8 ghcide-2.0.0.0-JM9QCNP1INWKrAoPjE8FRX
    hls-explicit-imports-plugin-2.0.0.0-3cxhrnB3eJaGiuXv9qTfZ0
    hls-graph-2.0.0.0-Dwoowae560dEfZKoVLM8Ap
    hls-plugin-api-2.0.0.0-9jtDVNQxl6AAbI62A2CMtD
    lsp-1.6.0.0-LaIZzQ4nrlw5ebiwaBE0Bs text-2.0.2
    unordered-containers-0.2.20-Jl6TkouWI2i1D1jczNV0uv

haddock-interfaces:
    /usr/share/doc/haskell-hls-refine-imports-plugin/html/hls-refine-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refine-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
